from holehe.core import *
from holehe.localuseragent import *


async def zoho(email, client, out):
    name = "zoho"
    domain = "zoho.com"
    method= "register"
    frequent_rate_limit=False

    headers = {
        'User-Agent': random.choice(ua["browsers"]["chrome"]),
        'Content-Type': 'application/x-www-form-urlencoded;charset=UTF-8',
        'Accept': '*/*',
        'Origin': 'https://accounts.zoho.com',
        'Sec-Fetch-Site': 'same-origin',
        'Sec-Fetch-Mode': 'cors',
        'Sec-Fetch-Dest': 'empty',
        'Accept-Language': 'en-US;q=0.8,en;q=0.7',
    }

    response = await client.get("https://accounts.zoho.com/register", headers=headers)
    headers['X-ZCSRF-TOKEN']='iamcsrcoo='+response.cookies["iamcsr"]

    data = {
      'mode': 'primary',
      'servicename': 'ZohoCRM',
      'serviceurl': 'https://crm.zoho.com/crm/ShowHomePage.do',
      'service_language': 'fr'
    }

    response = await client.post('https://accounts.zoho.com/signin/v2/lookup/'+email, headers=headers, data=data)
    if response.status_code==200 and "message" in response.json().keys() and response.json()["message"]=="User exists" and response.json()["status_code"]==201:
        out.append({"name": name,"domain":domain,"method":method,"frequent_rate_limit":frequent_rate_limit,
                    "rateLimit": False,
                    "exists": True,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})
    elif response.status_code==200 and "message" in response.json().keys() and response.json()["status_code"]==400:
        out.append({"name": name,"domain":domain,"method":method,"frequent_rate_limit":frequent_rate_limit,
                    "rateLimit": False,
                    "exists": False,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})
    else:
        out.append({"name": name,"domain":domain,"method":method,"frequent_rate_limit":frequent_rate_limit,
                    "rateLimit": True,
                    "exists": False,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})
    return()



import trio
from tqdm import tqdm

class TrioProgress(trio.abc.Instrument):
    def __init__(self, total):
        self.tqdm = tqdm(total=total)

    def task_exited(self, task):
        if task.name.split(".")[-1] == "launch_module":
            self.tqdm.update(1)


from holehe.core import *
from holehe.localuseragent import *


async def amazon(email, client, out):
    name = "amazon"
    domain = "amazon.com"
    method = "login"
    frequent_rate_limit=False

    headers = {"User-agent": random.choice(ua["browsers"]["chrome"])}
    try:
        url = "https://www.amazon.com/ap/signin?openid.pape.max_auth_age=0&openid.return_to=https%3A%2F%2Fwww.amazon.com%2F%3F_encoding%3DUTF8%26ref_%3Dnav_ya_signin&openid.identity=http%3A%2F%2Fspecs.openid.net%2Fauth%2F2.0%2Fidentifier_select&openid.assoc_handle=usflex&openid.mode=checkid_setup&openid.claimed_id=http%3A%2F%2Fspecs.openid.net%2Fauth%2F2.0%2Fidentifier_select&openid.ns=http%3A%2F%2Fspecs.openid.net%2Fauth%2F2.0&"
        req = await client.get(url, headers=headers)
        body = BeautifulSoup(req.text, 'html.parser')
        data = dict([(x["name"], x["value"]) for x in body.select(
            'form input') if ('name' in x.attrs and 'value' in x.attrs)])
        data["email"] = email
        req = await client.post(f'https://www.amazon.com/ap/signin/', data=data)
        body = BeautifulSoup(req.text, 'html.parser')
        if body.find("div", {"id": "auth-password-missing-alert"}):
            out.append({"name": name,"domain":domain,"method":method,"frequent_rate_limit":frequent_rate_limit,
                        "rateLimit": False,
                        "exists": True,
                        "emailrecovery": None,
                        "phoneNumber": None,
                        "others": None})
        else:
            out.append({"name": name,"domain":domain,"method":method,"frequent_rate_limit":frequent_rate_limit,
                        "rateLimit": False,
                        "exists": False,
                        "emailrecovery": None,
                        "phoneNumber": None,
                        "others": None})
    except :
        out.append({"name": name,"domain":domain,"method":method,"frequent_rate_limit":frequent_rate_limit,
                    "rateLimit": True,
                    "exists": False,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})



from holehe.core import *
from holehe.localuseragent import *


async def lastfm(email, client, out):
    name = "lastfm"
    domain = "last.fm"
    method= "register"
    frequent_rate_limit=False

    try:
        req = await client.get("https://www.last.fm/join")
        token = req.cookies["csrftoken"]
    except BaseException:
        out.append({"name": name,"domain":domain,"method":method,"frequent_rate_limit":frequent_rate_limit,
                    "rateLimit": True,
                    "exists": False,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})
        return None

    data = {"csrfmiddlewaretoken": token, "userName": "", "email": email}
    headers = {
        "Accept": "*/*",
        "Referer": "https://www.last.fm/join",
        "X-Requested-With": "XMLHttpRequest",
        "Cookie": "csrftoken=" + str(token),
    }
    try:

        check = await client.post("https://www.last.fm/join/partial/validate", headers=headers, data=data)
    except BaseException:
        out.append({"name": name,"domain":domain,"method":method,"frequent_rate_limit":frequent_rate_limit,
                    "rateLimit": True,
                    "exists": False,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})
        return None

    if check.json()["email"]["valid"]:
        out.append({"name": name,"domain":domain,"method":method,"frequent_rate_limit":frequent_rate_limit,
                    "rateLimit": False,
                    "exists": False,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})
    else:
        out.append({"name": name,"domain":domain,"method":method,"frequent_rate_limit":frequent_rate_limit,
                    "rateLimit": False,
                    "exists": True,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})



from holehe.core import *
from holehe.localuseragent import *


async def insightly(email, client, out):
    name = "insightly"
    domain = "insightly.com"
    method= "register"
    frequent_rate_limit=False

    headers = {
        'authority': 'accounts.insightly.com',
        'accept': 'application/json, text/javascript, */*; q=0.01',
        'x-requested-with': 'XMLHttpRequest',
        'User-Agent': random.choice(ua["browsers"]["chrome"]),
        'content-type': 'application/x-www-form-urlencoded; charset=UTF-8',
        'origin': 'https://accounts.insightly.com',
        'sec-fetch-site': 'same-origin',
        'sec-fetch-mode': 'cors',
        'sec-fetch-dest': 'empty',
        'referer': 'https://accounts.insightly.com/?plan=trial',
        'accept-language': 'en-US;q=0.8,en;q=0.7',
    }

    data = {
      'emailaddress': email
    }

    response = await client.post('https://accounts.insightly.com/signup/isemailvalid', headers=headers, data=data)

    if "An account exists for this address. Use another address or" in response.text:
        out.append({"name": name,"domain":domain,"method":method,"frequent_rate_limit":frequent_rate_limit,
                    "rateLimit": False,
                    "exists": True,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})
        return()
    elif response.text == "true":
        out.append({"name": name,"domain":domain,"method":method,"frequent_rate_limit":frequent_rate_limit,
                    "rateLimit": False,
                    "exists": False,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})
        return()

    out.append({"name": name,"domain":domain,"method":method,"frequent_rate_limit":frequent_rate_limit,
                "rateLimit": True,
                "exists": False,
                "emailrecovery": None,
                "phoneNumber": None,
                "others": None})
    return()



from holehe.core import *
from holehe.localuseragent import *


async def pipedrive(email, client, out):
    name = "pipedrive"
    domain = "pipedrive.com"
    method= "register"
    frequent_rate_limit=False


    headers = {
        'authority': 'app.pipedrive.com',
        'accept': 'application/json',
        'User-Agent': random.choice(ua["browsers"]["chrome"]),
        'content-type': 'application/json',
        'origin': 'https://www.pipedrive.com',
        'sec-fetch-site': 'same-site',
        'sec-fetch-mode': 'cors',
        'sec-fetch-dest': 'empty',
        'referer': 'https://www.pipedrive.com/',
        'accept-language': 'en-US;q=0.8,en;q=0.7',
    }
    data = '{"email":"'+email+'","language":"fr","country_code":"fr","selectedTier":null,"packages":[]}'

    response = await client.post('https://app.pipedrive.com/signup-service/start', headers=headers, data=data)
    if response.status_code==200:
        if "errors" in response.json().keys() and "user_email" in response.json()["errors"].keys() and  "Email is not available" in response.json()["errors"]["user_email"]:
            out.append({"name": name,"domain":domain,"method":method,"frequent_rate_limit":frequent_rate_limit,
                        "rateLimit": False,
                        "exists": True,
                        "emailrecovery": None,
                        "phoneNumber": None,
                        "others": None})
            return()
        elif "data" in response.json().keys() and "redirectUrl" in response.json()["data"].keys() and response.json()["data"]["redirectUrl"] == "https://app.pipedrive.com/signup-service":
            out.append({"name": name,"domain":domain,"method":method,"frequent_rate_limit":frequent_rate_limit,
                        "rateLimit": False,
                        "exists": False,
                        "emailrecovery": None,
                        "phoneNumber": None,
                        "others": None})
            return()

    out.append({"name": name,"domain":domain,"method":method,"frequent_rate_limit":frequent_rate_limit,
                "rateLimit": True,
                "exists": False,
                "emailrecovery": None,
                "phoneNumber": None,
                "others": None})
    return()



from holehe.core import *
from holehe.localuseragent import *


async def nutshell(email, client, out):
    name = "nutshell"
    domain = "nutshell.com"
    method= "register"
    frequent_rate_limit=False

    headers = {
        'authority': 'app.nutshell.com',
        'accept': '*/*',
        'User-Agent': random.choice(ua["browsers"]["chrome"]),
        'content-type': 'application/x-www-form-urlencoded',
        'origin': 'https://app.nutshell.com',
        'sec-fetch-site': 'same-origin',
        'sec-fetch-mode': 'cors',
        'sec-fetch-dest': 'empty',
        'referer': 'https://app.nutshell.com/auth',
        'accept-language': 'en-US;q=0.8,en;q=0.7',
    }

    data = {
      'via': 'database',
      'timezone_offset': '1',
      'remember_me': 'true',
      'username': email,
      'invalidToken': 'false',
      'password': 'a'
    }

    response = await client.post('https://app.nutshell.com/auth', headers=headers, data=data)

    if "Sorry, your password is incorrect" in response.text:
        out.append({"name": name,"domain":domain,"method":method,"frequent_rate_limit":frequent_rate_limit,
                    "rateLimit": False,
                    "exists": True,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})
    elif "find a Nutshell account for that email address." in response.text:
        out.append({"name": name,"domain":domain,"method":method,"frequent_rate_limit":frequent_rate_limit,
                    "rateLimit": False,
                    "exists": False,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})
    else:
        out.append({"name": name,"domain":domain,"method":method,"frequent_rate_limit":frequent_rate_limit,
                    "rateLimit": True,
                    "exists": False,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})
    return()



from holehe.core import *
from holehe.localuseragent import *


async def amocrm(email, client, out):
    name = "amocrm"
    domain = "amocrm.com"
    method= "register"
    frequent_rate_limit=False

    headers = {
        'Connection': 'keep-alive',
        'Accept': '*/*',
        'X-Requested-With': 'XMLHttpRequest',
        'User-Agent': random.choice(ua["browsers"]["chrome"]),
        'Content-Type': 'application/x-www-form-urlencoded; charset=UTF-8',
        'Origin': 'https://www.amocrm.com',
        'Sec-Fetch-Site': 'same-origin',
        'Sec-Fetch-Mode': 'cors',
        'Sec-Fetch-Dest': 'empty',
        'Referer': 'https://www.amocrm.com/',
        'Accept-Language': 'fr-FR,fr;q=0.9,en-US;q=0.8,en;q=0.7',
    }

    data = {
      'LOGIN': email
    }

    response = await client.post('https://www.amocrm.com/account/check_login.php', headers=headers, data=data)
    if response.status_code==200 and response.json()["status"]=="used":
        out.append({"name": name,"domain":domain,"method":method,"frequent_rate_limit":frequent_rate_limit,
                    "rateLimit": False,
                    "exists": True,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})
    elif response.status_code==200 and response.json()["status"]=="free":
        out.append({"name": name,"domain":domain,"method":method,"frequent_rate_limit":frequent_rate_limit,
                    "rateLimit": False,
                    "exists": False,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})
    else :
        out.append({"name": name,"domain":domain,"method":method,"frequent_rate_limit":frequent_rate_limit,
                    "rateLimit": True,
                    "exists": False,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})
    return()



from holehe.core import *
from holehe.localuseragent import *


async def nocrm(email, client, out):
    name = "nocrm"
    domain = "nocrm.io"
    method= "register"
    frequent_rate_limit=False

    headers = {
        'authority': 'register.nocrm.io',
        'accept': 'application/json, text/javascript, */*; q=0.01',
        'User-Agent': random.choice(ua["browsers"]["chrome"]),
        'x-requested-with': 'XMLHttpRequest',
        'sec-fetch-site': 'same-origin',
        'sec-fetch-mode': 'cors',
        'sec-fetch-dest': 'empty',
        'referer': 'https://register.nocrm.io/?lang=en&cc=FR&edition=dreamteam&site_version=v3-video-sun-fr&first_seen_from=https%3A%2F%2Fyoudontneedacrm.com%2Ffr&first_seen_on=%2Ffr&fp_tracking=',
        'accept-language': 'en-US;q=0.8,en;q=0.7',
    }


    response = await client.get('https://register.nocrm.io/register/check_trial_duplicate?email='+email, headers=headers)
    if '{"account":1,"url":"' in response.text:
        out.append({"name": name,"domain":domain,"method":method,"frequent_rate_limit":frequent_rate_limit,
                    "rateLimit": False,
                    "exists": True,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})
    elif response.text == '{"account":0}':
        out.append({"name": name,"domain":domain,"method":method,"frequent_rate_limit":frequent_rate_limit,
                    "rateLimit": False,
                    "exists": False,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})
    else:
        out.append({"name": name,"domain":domain,"method":method,"frequent_rate_limit":frequent_rate_limit,
                    "rateLimit": True,
                    "exists": False,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})
    return()



from holehe.core import *
from holehe.localuseragent import *


async def hubspot(email, client, out):
    name = "hubspot"
    domain = "hubspot.com"
    method= "login"
    frequent_rate_limit=False


    headers = {
        'authority': 'api.hubspot.com',
        'User-Agent': random.choice(ua["browsers"]["chrome"]),
        'content-type': 'application/json',
        'origin': 'https://app.hubspot.com',
        'sec-fetch-site': 'same-site',
        'sec-fetch-mode': 'cors',
        'sec-fetch-dest': 'empty',
        'referer': 'https://app.hubspot.com/',
        'accept-language': 'en-US;q=0.8,en;q=0.7',
    }

    data = '{"email":"'+email+'","password":"","rememberLogin":false}'

    response = await client.post('https://api.hubspot.com/login-api/v1/login', headers=headers, data=data)
    if response.status_code == 400:
        if response.json()["status"]=="INVALID_PASSWORD":
            out.append({"name": name,"domain":domain,"method":method,"frequent_rate_limit":frequent_rate_limit,
                        "rateLimit": False,
                        "exists": True,
                        "emailrecovery": None,
                        "phoneNumber": None,
                        "others": None})
        elif response.json()["status"]=="INVALID_USER":
            out.append({"name": name,"domain":domain,"method":method,"frequent_rate_limit":frequent_rate_limit,
                        "rateLimit": False,
                        "exists": False,
                        "emailrecovery": None,
                        "phoneNumber": None,
                        "others": None})
        return()
    out.append({"name": name,"domain":domain,"method":method,"frequent_rate_limit":frequent_rate_limit,
                "rateLimit": True,
                "exists": False,
                "emailrecovery": None,
                "phoneNumber": None,
                "others": None})
    return()



from holehe.core import *
from holehe.localuseragent import *


async def nimble(email, client, out):
    name = "nimble"
    domain = "nimble.com"
    method= "register"
    frequent_rate_limit=False

    headers = {
        'Connection': 'keep-alive',
        'Accept': 'application/json, text/javascript, */*; q=0.01',
        'X-Requested-With': 'XMLHttpRequest',
        'User-Agent': random.choice(ua["browsers"]["chrome"]),
        'Sec-Fetch-Site': 'same-origin',
        'Sec-Fetch-Mode': 'cors',
        'Sec-Fetch-Dest': 'empty',
        'Referer': 'https://www.nimble.com/',
        'Accept-Language': 'en-US;q=0.8,en;q=0.7',
    }

    response = await client.get('https://www.nimble.com/lib/register.php?email='+email, headers=headers)

    if response.text=='"I thought you looked familiar! This email is already registered."':
        out.append({"name": name,"domain":domain,"method":method,"frequent_rate_limit":frequent_rate_limit,
                    "rateLimit": False,
                    "exists": True,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})
    elif response.text=="true":
        out.append({"name": name,"domain":domain,"method":method,"frequent_rate_limit":frequent_rate_limit,
                    "rateLimit": False,
                    "exists": False,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})
    else:
        out.append({"name": name,"domain":domain,"method":method,"frequent_rate_limit":frequent_rate_limit,
                    "rateLimit": True,
                    "exists": False,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})
    return()



from holehe.core import *
from holehe.localuseragent import *


async def teamleader(email, client, out):
    name = "teamleader"
    domain = "teamleader.eu"
    method= "register"
    frequent_rate_limit=False

    headers = {
        'authority': 'focus.teamleader.eu',
        'User-Agent': random.choice(ua["browsers"]["chrome"]),
        'content-type': 'application/json',
        'accept': '*/*',
        'origin': 'https://signup.focus.teamleader.fr',
        'sec-fetch-site': 'cross-site',
        'sec-fetch-mode': 'cors',
        'sec-fetch-dest': 'empty',
        'referer': 'https://signup.focus.teamleader.fr/',
        'accept-language': 'en-US;q=0.8,en;q=0.7',
    }

    data = '{"email":"'+email+'"}'

    response = await client.post('https://focus.teamleader.eu/app/emails/availability', headers=headers, data=data)
    if response.text=='{"available":false}':
        out.append({"name": name,"domain":domain,"method":method,"frequent_rate_limit":frequent_rate_limit,
                    "rateLimit": False,
                    "exists": True,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})
    elif response.text=='{"available":true}':
        out.append({"name": name,"domain":domain,"method":method,"frequent_rate_limit":frequent_rate_limit,
                    "rateLimit": False,
                    "exists": False,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})
    else:
        out.append({"name": name,"domain":domain,"method":method,"frequent_rate_limit":frequent_rate_limit,
                    "rateLimit": True,
                    "exists": False,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})

    return()



from holehe.core import *
from holehe.localuseragent import *


async def axonaut(email, client, out):
    name = "axonaut"
    domain = "axonaut.com"
    method= "register"
    frequent_rate_limit=False

    headers = {
        'authority': 'axonaut.com',
        'upgrade-insecure-requests': '1',
        'User-Agent': random.choice(ua["browsers"]["chrome"]),
        'accept': 'text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.9',
        'sec-fetch-site': 'same-origin',
        'sec-fetch-mode': 'navigate',
        'sec-fetch-user': '?1',
        'sec-fetch-dest': 'document',
        'referer': 'https://axonaut.com/en',
        'accept-language': 'en-US;q=0.8,en;q=0.7',
    }


    response = await client.get('https://axonaut.com/onboarding/?email='+email, headers=headers,allow_redirects=False)

    if response.status_code == 302 and "/login?email" in str(response.headers['Location']):
        out.append({"name": name,"domain":domain,"method":method,"frequent_rate_limit":frequent_rate_limit,
                    "rateLimit": False,
                    "exists": True,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})
    elif response.status_code ==200:
        out.append({"name": name,"domain":domain,"method":method,"frequent_rate_limit":frequent_rate_limit,
                    "rateLimit": False,
                    "exists": False,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})
    else:
        out.append({"name": name,"domain":domain,"method":method,"frequent_rate_limit":frequent_rate_limit,
                    "rateLimit": True,
                    "exists": False,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})
    return()
